@@ -165,4 +165,12 @@ pub struct LspWorkspaceDiagnostic {
     ///
     /// Whether to enable workspace diagnostic.
     pub enabled: Option<BoolDefaultTrue>,
+
+    /// # Throttle interval in seconds
+    ///
+    /// **🚧 Deprecated 🚧**\
+    /// Don't need to use this option.
+    ///
+    #[cfg_attr(feature = "jsonschema", deprecated)]
+    pub throttle_seconds: Option<u64>,
 }
