@@ -4,10 +4,11 @@ mod completion_kind;
 
 use std::ops::Deref;
 
-pub use completion_edit::CompletionEdit;
+pub use completion_edit::{CompletionEdit, CompletionTextEdit, InsertReplaceEdit};
 pub use completion_hint::{AddLeadingComma, AddTrailingComma, CommaHint, CompletionHint};
 pub use completion_kind::CompletionKind;
 use tombi_schema_store::{get_schema_name, SchemaUri};
+use tombi_text::{FromLsp, IntoLsp};
 
 use crate::get_tombi_github_uri;
 
@@ -31,8 +32,8 @@ impl CompletionContentPriority {
     pub fn as_prefix(&self) -> String {
         match self {
             CompletionContentPriority::Custom(value) => value.to_string(),
-            // NOTE: 30 is the prefix for completion items from extensions
-            //       that should be prioritized over basic features.
+            // NOTE: Completion candidates provided by extensions are assigned priority numbers starting from 50,
+            //       allowing them to be placed above basic features.
             CompletionContentPriority::Default => "50".to_string(),
             CompletionContentPriority::Const => "51".to_string(),
             CompletionContentPriority::Enum => "52".to_string(),
@@ -455,18 +456,17 @@ impl CompletionContent {
     }
 }
 
-impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
-    fn from(completion_content: CompletionContent) -> Self {
+impl FromLsp<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
+    fn from_lsp(
+        source: CompletionContent,
+        line_index: &tombi_text::LineIndex,
+    ) -> tower_lsp::lsp_types::CompletionItem {
         const SECTION_SEPARATOR: &str = "-----";
 
-        let sorted_text = format!(
-            "{}_{}",
-            completion_content.priority.as_prefix(),
-            &completion_content.label
-        );
+        let sorted_text = format!("{}_{}", source.priority.as_prefix(), &source.label);
 
         let mut schema_text = None;
-        if let Some(schema_uri) = &completion_content.schema_uri {
+        if let Some(schema_uri) = &source.schema_uri {
             let schema_uri = match get_tombi_github_uri(schema_uri) {
                 Some(schema_uri) => schema_uri,
                 None => schema_uri.deref().clone(),
@@ -475,7 +475,7 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
                 schema_text = Some(format!("Schema: [{schema_filename}]({schema_uri})\n"));
             }
         }
-        let documentation = match completion_content.documentation {
+        let documentation = match source.documentation {
             Some(documentation) => {
                 let mut documentation = documentation;
                 if let Some(schema_text) = schema_text {
@@ -487,26 +487,31 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
             None => schema_text,
         };
 
-        let (insert_text_format, text_edit, additional_text_edits) = match completion_content.edit {
+        let (insert_text_format, text_edit, additional_text_edits) = match source.edit {
             Some(edit) => (
                 edit.insert_text_format,
-                Some(edit.text_edit),
-                edit.additional_text_edits,
+                Some(edit.text_edit.into_lsp(line_index)),
+                edit.additional_text_edits.map(|edits| {
+                    edits
+                        .into_iter()
+                        .map(|edit| edit.into_lsp(line_index))
+                        .collect()
+                }),
             ),
             None => (None, None, None),
         };
 
-        let label_details = match completion_content.priority {
+        let label_details = match source.priority {
             CompletionContentPriority::Custom(_) => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: None,
-                    description: completion_content.detail.clone(),
+                    description: source.detail.clone(),
                 })
             }
             CompletionContentPriority::Default => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: None,
-                    description: Some(match &completion_content.detail {
+                    description: Some(match &source.detail {
                         Some(detail) => format!("[Default] {detail}"),
                         None => "Default".to_string(),
                     }),
@@ -515,7 +520,7 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
             CompletionContentPriority::Const => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: None,
-                    description: Some(match &completion_content.detail {
+                    description: Some(match &source.detail {
                         Some(detail) => detail.to_string(),
                         None => "Const".to_string(),
                     }),
@@ -524,7 +529,7 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
             CompletionContentPriority::Enum => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: None,
-                    description: Some(match &completion_content.detail {
+                    description: Some(match &source.detail {
                         Some(detail) => detail.to_string(),
                         None => "Enum".to_string(),
                     }),
@@ -533,13 +538,13 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
             CompletionContentPriority::Key => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: None,
-                    description: completion_content.detail.clone(),
+                    description: source.detail.clone(),
                 })
             }
             CompletionContentPriority::OptionalKey | CompletionContentPriority::AdditionalKey => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: Some("?".to_string()),
-                    description: completion_content.detail.clone(),
+                    description: source.detail.clone(),
                 })
             }
             CompletionContentPriority::TypeHint
@@ -548,7 +553,7 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
             | CompletionContentPriority::TypeHintFalse => {
                 Some(tower_lsp::lsp_types::CompletionItemLabelDetails {
                     detail: None,
-                    description: Some(match &completion_content.detail {
+                    description: Some(match &source.detail {
                         Some(detail) if !detail.trim().is_empty() => detail.clone(),
                         _ => "Type Hint".to_string(),
                     }),
@@ -556,7 +561,7 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
             }
         }
         .map(|mut details| {
-            if let Some(emoji_icon) = completion_content.emoji_icon {
+            if let Some(emoji_icon) = source.emoji_icon {
                 details.description = Some(format!(
                     "{} {}",
                     emoji_icon,
@@ -567,11 +572,11 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
         });
 
         tower_lsp::lsp_types::CompletionItem {
-            label: completion_content.label,
+            label: source.label,
             label_details,
-            kind: Some(completion_content.kind.into()),
-            detail: completion_content.detail.map(|detail| {
-                if let Some(emoji_icon) = completion_content.emoji_icon {
+            kind: Some(source.kind.into()),
+            detail: source.detail.map(|detail| {
+                if let Some(emoji_icon) = source.emoji_icon {
                     format!("{emoji_icon} {detail}")
                 } else {
                     detail
@@ -586,13 +591,13 @@ impl From<CompletionContent> for tower_lsp::lsp_types::CompletionItem {
                 )
             }),
             sort_text: Some(sorted_text),
-            filter_text: completion_content.filter_text,
+            filter_text: source.filter_text,
             insert_text_format,
             text_edit,
             insert_text_mode: Some(tower_lsp::lsp_types::InsertTextMode::ADJUST_INDENTATION),
             additional_text_edits,
-            preselect: completion_content.preselect,
-            deprecated: completion_content.deprecated,
+            preselect: source.preselect,
+            deprecated: source.deprecated,
             ..Default::default()
         }
     }
