@@ -24,7 +24,7 @@ pub(crate) fn exceeds_line_width(
 ) -> Result<bool, std::fmt::Error> {
     let mut length = f.current_line_width();
     length += 2; // '[' and ']'
-    length += f.singleline_array_bracket_inner_space().len() * 2; // Space after '[' and before ']'
+    length += f.array_bracket_space().len() * 2; // Space after '[' and before ']'
     let mut first = true;
 
     for value in node.values() {
@@ -47,7 +47,7 @@ pub(crate) fn exceeds_line_width(
         // Calculate total length
         if !first {
             length += 1; // ","
-            length += f.singleline_array_space_after_comma().len();
+            length += f.array_comma_space().len();
         }
         length += f.format_to_string(&value)?.graphemes(true).count();
         first = false;
@@ -146,17 +146,17 @@ fn format_singleline_array(
     array.leading_comments().collect_vec().format(f)?;
 
     f.write_indent()?;
-    write!(f, "[{}", f.singleline_array_bracket_inner_space())?;
+    write!(f, "[{}", f.array_bracket_space())?;
 
     for (i, value) in array.values().enumerate() {
         if i > 0 {
-            write!(f, ",{}", f.singleline_array_space_after_comma())?;
+            write!(f, ",{}", f.array_comma_space())?;
         }
         f.skip_indent();
         value.format(f)?;
     }
 
-    write!(f, "{}]", f.singleline_array_bracket_inner_space())?;
+    write!(f, "{}]", f.array_bracket_space())?;
 
     if let Some(comment) = array.trailing_comment() {
         comment.format(f)?;
@@ -168,10 +168,10 @@ fn format_singleline_array(
 #[cfg(test)]
 mod tests {
     use rstest::rstest;
-    use tombi_config::{QuoteStyle, TomlVersion};
+    use tombi_config::{format::FormatRules, FormatOptions, QuoteStyle, TomlVersion};
 
     use super::*;
-    use crate::{formatter::definitions::FormatDefinitions, test_format};
+    use crate::test_format;
 
     test_format! {
         #[test]
@@ -220,8 +220,11 @@ mod tests {
         fn singleline_array7(
             r#"string_array = [ "all", 'strings', """are the same""", '''type''' ]"#,
             TomlVersion::default(),
-            &FormatDefinitions {
-                quote_style: Some(QuoteStyle::Preserve),
+            &FormatOptions {
+                rules: Some(FormatRules {
+                    quote_style: Some(QuoteStyle::Preserve),
+                    ..Default::default()
+                }),
                 ..Default::default()
             }
         ) -> Ok(r#"string_array = ["all", 'strings', """are the same""", '''type''']"#);
@@ -458,8 +461,11 @@ mod tests {
         fn array_exceeds_line_width(
             r#"array = [1111111111, 2222222222, 3333333333]"#,
             Default::default(),
-            &FormatDefinitions {
-                line_width: Some(20.try_into().unwrap()),
+            &FormatOptions {
+                rules: Some(FormatRules {
+                    line_width: Some(20.try_into().unwrap()),
+                    ..Default::default()
+                }),
                 ..Default::default()
             }
         ) -> Ok(
@@ -478,8 +484,11 @@ mod tests {
         fn array_with_nested_array_exceeds_line_width(
             r#"array = [[1111111111, 2222222222], [3333333333, 4444444444]]"#,
             Default::default(),
-            &FormatDefinitions {
-                line_width: Some(30.try_into().unwrap()),
+            &FormatOptions {
+                rules: Some(FormatRules {
+                    line_width: Some(30.try_into().unwrap()),
+                    ..Default::default()
+                }),
                 ..Default::default()
             }
         ) -> Ok(
@@ -497,8 +506,11 @@ mod tests {
         fn array_with_nested_inline_table_exceeds_line_width(
             r#"array = [{ key1 = 1111111111, key2 = 2222222222 }, { key3 = [3333333333, 4444444444], key4 = [5555555555, 6666666666, 7777777777] }]"#,
             TomlVersion::V1_1_0_Preview,
-            &FormatDefinitions {
-                line_width: Some(35.try_into().unwrap()),
+            &FormatOptions {
+                rules: Some(FormatRules {
+                    line_width: Some(35.try_into().unwrap()),
+                    ..Default::default()
+                }),
                 ..Default::default()
             }
         ) -> Ok(
