@@ -74,9 +74,9 @@ impl LiteralNode for tombi_ast::MultiLineLiteralString {
 
 #[cfg(test)]
 mod tests {
-    use tombi_config::{QuoteStyle, TomlVersion};
+    use tombi_config::{format::FormatRules, FormatOptions, QuoteStyle, TomlVersion};
 
-    use crate::{test_format, FormatDefinitions};
+    use crate::test_format;
 
     test_format! {
         #[test]
@@ -93,8 +93,11 @@ mod tests {
         fn basic_string_value_quote_style_single1(
             r#"key = "value""#,
             TomlVersion::default(),
-            &FormatDefinitions {
-                quote_style: Some(QuoteStyle::Single),
+            &FormatOptions {
+                rules: Some(FormatRules {
+                    quote_style: Some(QuoteStyle::Single),
+                    ..Default::default()
+                }),
                 ..Default::default()
             }
         ) -> Ok(r#"key = 'value'"#);
@@ -105,8 +108,11 @@ mod tests {
         fn basic_string_value_quote_style_single2(
             r#"key = "'value'""#,
             TomlVersion::default(),
-            &FormatDefinitions {
-                quote_style: Some(QuoteStyle::Single),
+            &FormatOptions {
+                rules: Some(FormatRules {
+                    quote_style: Some(QuoteStyle::Single),
+                    ..Default::default()
+                }),
                 ..Default::default()
             }
         ) -> Ok(source);
