@@ -365,7 +365,7 @@ mod table_keys_order {
                 r#"
                 [tool.maturin]
                 include = [
-                  { path = "json.schemastore.org/**/*.json", format = "sdist" },
+                  { path = "www.schemastore.org/**/*.json", format = "sdist" },
                   { path = "json.tombi.dev/**/*.json", format = "sdist" },
                 ]
                 "#,
@@ -374,7 +374,7 @@ mod table_keys_order {
                 r#"
                 [tool.maturin]
                 include = [
-                  { format = "sdist", path = "json.schemastore.org/**/*.json" },
+                  { format = "sdist", path = "www.schemastore.org/**/*.json" },
                   { format = "sdist", path = "json.tombi.dev/**/*.json" },
                 ]
                 "#
@@ -1582,7 +1582,7 @@ mod table_keys_order {
             async fn $name() {
                 use textwrap::dedent;
                 use tombi_config::TomlVersion;
-                use tombi_formatter::{FormatDefinitions, FormatOptions, Formatter};
+                use tombi_formatter::{FormatOptions, Formatter};
                 use tombi_schema_store::SchemaStore;
 
                 tombi_test_lib::init_tracing();
@@ -1608,12 +1608,10 @@ mod table_keys_order {
                 }
 
                 // Initialize formatter
-                let format_definitions = &FormatDefinitions::default();
                 let format_options = FormatOptions::default();
                 let source_path = tombi_test_lib::project_root_path().join("test.toml");
                 let formatter = Formatter::new(
                     $toml_version,
-                    format_definitions,
                     &format_options,
                     Some(itertools::Either::Right(source_path.as_path())),
                     &schema_store,
