@@ -2,10 +2,11 @@ use std::path::PathBuf;
 
 use ahash::AHashMap;
 use itertools::{Either, Itertools};
-use tombi_config::{Config, ConfigLevel, LintOptions};
+use tombi_config::{Config, LintOptions};
 use tombi_glob::{matches_file_patterns, MatchResult};
+use tombi_text::IntoLsp;
 
-use crate::{backend::Backend, config_manager::ConfigSchemaStore, document::DocumentSource};
+use crate::{backend::Backend, config_manager::ConfigSchemaStore};
 
 pub async fn publish_diagnostics(
     backend: &Backend,
@@ -20,6 +21,11 @@ pub async fn publish_diagnostics(
         return;
     };
 
+    // Preventing the publishing of duplicate diagnoses.
+    if old_version.is_some() || version.is_none() {
+        return;
+    }
+
     backend
         .client
         .publish_diagnostics(
@@ -76,41 +82,27 @@ pub async fn get_diagnostics_result(
         }
     }
 
-    let root = backend.get_incomplete_ast(text_document_uri).await?;
-
-    let source_schema = schema_store
-        .resolve_source_schema_from_ast(&root, Some(Either::Left(text_document_uri)))
-        .await
-        .ok()
-        .flatten();
-
-    let tombi_document_comment_directive =
-        tombi_validator::comment_directive::get_tombi_document_comment_directive(&root).await;
-    let (toml_version, _) = backend
-        .source_toml_version(
-            tombi_document_comment_directive,
-            source_schema.as_ref(),
-            &config,
-        )
-        .await;
-
     let document_sources = backend.document_sources.read().await;
 
     match document_sources.get(text_document_uri) {
-        Some(document) => Some(DiagnosticsResult {
+        Some(document_source) => Some(DiagnosticsResult {
             diagnostics: match tombi_linter::Linter::new(
-                toml_version,
+                document_source.toml_version,
                 config.lint.as_ref().unwrap_or(&LintOptions::default()),
                 Some(Either::Left(text_document_uri)),
                 &schema_store,
             )
-            .lint(&document.text)
+            .lint(document_source.text())
             .await
             {
                 Ok(_) => Vec::with_capacity(0),
-                Err(diagnostics) => diagnostics.into_iter().unique().map(Into::into).collect(),
+                Err(diagnostics) => diagnostics
+                    .into_iter()
+                    .unique()
+                    .map(|diagnostic| diagnostic.into_lsp(document_source.line_index()))
+                    .collect_vec(),
             },
-            version: document.version,
+            version: document_source.version,
         }),
         None => None,
     }
@@ -120,8 +112,6 @@ pub async fn get_diagnostics_result(
 pub struct WorkspaceConfig {
     pub workspace_folder_path: PathBuf,
     pub config: Config,
-    pub config_path: Option<PathBuf>,
-    pub config_level: ConfigLevel,
 }
 
 pub async fn get_workspace_configs(
@@ -150,87 +140,17 @@ pub async fn get_workspace_configs(
     let mut configs = AHashMap::new();
 
     for workspace_folder_path in workspace_folder_paths {
-        if let Ok((config, config_path, config_level)) =
-            serde_tombi::config::load_with_path_and_level(Some(workspace_folder_path.clone()))
+        if let Ok((config, config_path)) =
+            serde_tombi::config::load_with_path(Some(workspace_folder_path.clone()))
         {
             configs
                 .entry(config_path.clone())
                 .or_insert(WorkspaceConfig {
                     workspace_folder_path,
                     config,
-                    config_path,
-                    config_level,
                 });
         };
     }
 
     Some(configs)
 }
-
-#[derive(Debug)]
-pub struct WorkspaceDiagnosticTarget {
-    pub text_document_uri: tombi_uri::Uri,
-    pub version: Option<i32>,
-}
-
-pub async fn get_workspace_diagnostic_targets(
-    backend: &Backend,
-    workspace_config: &WorkspaceConfig,
-) -> Option<Vec<WorkspaceDiagnosticTarget>> {
-    let mut total_diagnostic_targets = Vec::new();
-
-    let WorkspaceConfig {
-        workspace_folder_path,
-        config,
-        config_level,
-        config_path,
-    } = workspace_config;
-
-    let workspace_folder_path_str = workspace_folder_path.to_str()?;
-    if let tombi_glob::FileSearch::Files(files) = tombi_glob::FileSearch::new(
-        &[workspace_folder_path_str],
-        config,
-        config_path.as_deref(),
-        *config_level,
-    )
-    .await
-    {
-        tracing::debug!(
-            "Found {} files in {}: {:?}",
-            files.len(),
-            workspace_folder_path_str,
-            files
-        );
-
-        for file in files {
-            let Ok(text_document_path) = file else {
-                continue;
-            };
-            if let Ok(text_document_uri) = tombi_uri::Uri::from_file_path(&text_document_path) {
-                let Ok(content) = tokio::fs::read_to_string(&text_document_path).await else {
-                    continue;
-                };
-                let version = {
-                    backend
-                        .document_sources
-                        .write()
-                        .await
-                        .entry(text_document_uri.clone())
-                        .or_insert_with(|| DocumentSource::new(content, None))
-                        .version
-                };
-
-                total_diagnostic_targets.push(WorkspaceDiagnosticTarget {
-                    text_document_uri,
-                    version,
-                });
-            }
-        }
-    }
-
-    if total_diagnostic_targets.is_empty() {
-        None
-    } else {
-        Some(total_diagnostic_targets)
-    }
-}
