@@ -4,7 +4,7 @@ use tower_lsp::lsp_types::{
 };
 
 use crate::{
-    backend::{Backend, DiagnosticType},
+    backend::{Backend, DiagnosticMode},
     diagnostic::{get_diagnostics_result, publish_diagnostics},
 };
 
@@ -39,7 +39,7 @@ pub async fn push_diagnostics(
     text_document_uri: tombi_uri::Uri,
     version: Option<i32>,
 ) {
-    if backend.capabilities.read().await.diagnostic_type != DiagnosticType::Push {
+    if backend.capabilities.read().await.diagnostic_mode != DiagnosticMode::Push {
         return;
     }
 
