@@ -11,9 +11,18 @@ pub async fn handle_did_open(backend: &Backend, params: DidOpenTextDocumentParam
 
     let text_document_uri: tombi_uri::Uri = text_document.uri.into();
     let mut document_sources = backend.document_sources.write().await;
+    let toml_version = backend
+        .text_document_toml_version(&text_document_uri, &text_document.text)
+        .await;
+
     document_sources.insert(
         text_document_uri.clone(),
-        DocumentSource::new(text_document.text, Some(text_document.version)),
+        DocumentSource::new(
+            text_document.text,
+            Some(text_document.version),
+            toml_version,
+            backend.capabilities.read().await.encoding_kind,
+        ),
     );
     drop(document_sources);
 
