@@ -6,7 +6,7 @@ use itertools::Itertools;
 use tombi_future::{BoxFuture, Boxable};
 use tombi_x_keyword::{
     ArrayValuesOrderBy, StringFormat, TableKeysOrder, TableKeysOrderGroupKind,
-    X_TOMBI_ARRAY_VALUES_ORDER_BY, X_TOMBI_TABLE_KEYS_ORDER,
+    X_TOMBI_ADDITIONAL_KEY_LABEL, X_TOMBI_ARRAY_VALUES_ORDER_BY, X_TOMBI_TABLE_KEYS_ORDER,
 };
 
 use super::{
@@ -39,6 +39,7 @@ pub struct TableSchema {
     pub enumerate: Option<Vec<tombi_json::Object>>,
     pub examples: Option<Vec<tombi_json::Object>>,
     pub deprecated: Option<bool>,
+    pub additional_key_label: Option<String>,
 }
 
 impl TableSchema {
@@ -189,6 +190,9 @@ impl TableSchema {
                         .collect()
                 }),
             deprecated: object_node.get("deprecated").and_then(|v| v.as_bool()),
+            additional_key_label: object_node
+                .get(X_TOMBI_ADDITIONAL_KEY_LABEL)
+                .and_then(|v| v.as_str().map(|s| s.to_string())),
         }
     }
 
