@@ -1,7 +1,9 @@
 pub mod comment_directive;
 mod diagnostic;
+mod error;
 mod validate;
 
 pub use comment_directive::get_tombi_value_comment_directive_and_diagnostics;
 pub use diagnostic::{Diagnostic, DiagnosticKind};
+pub use error::Error;
 pub use validate::{validate, Validate};
