@@ -154,27 +154,25 @@ async fn validate_boolean(
         }
     }
 
-    if diagnostics.is_empty() {
-        if boolean_schema.deprecated == Some(true) {
-            let level = lint_rules
-                .map(|rules| &rules.common)
-                .and_then(|rules| {
-                    rules
-                        .deprecated
-                        .as_ref()
-                        .map(SeverityLevelDefaultWarn::from)
-                })
-                .unwrap_or_default();
+    if diagnostics.is_empty() && boolean_schema.deprecated == Some(true) {
+        let level = lint_rules
+            .map(|rules| &rules.common)
+            .and_then(|rules| {
+                rules
+                    .deprecated
+                    .as_ref()
+                    .map(SeverityLevelDefaultWarn::from)
+            })
+            .unwrap_or_default();
 
-            crate::Diagnostic {
-                kind: Box::new(crate::DiagnosticKind::DeprecatedValue(
-                    tombi_schema_store::SchemaAccessors::from(accessors),
-                    value.to_string(),
-                )),
-                range,
-            }
-            .push_diagnostic_with_level(level, &mut diagnostics);
+        crate::Diagnostic {
+            kind: Box::new(crate::DiagnosticKind::DeprecatedValue(
+                tombi_schema_store::SchemaAccessors::from(accessors),
+                value.to_string(),
+            )),
+            range,
         }
+        .push_diagnostic_with_level(level, &mut diagnostics);
     }
 
     if diagnostics.is_empty() {
